@@ -1,22 +1,13 @@
 #
 # Run this Tcl script to generate the sqlite.html file.
 #
-set rcsid {$Id: arch.tcl,v 1.11 2004/03/14 11:57:58 drh Exp $}
-
-puts {<html>
-<head>
-  <title>Architecture of SQLite</title>
-</head>
-<body bgcolor=white>
-<h1 align=center>
-The Architecture Of SQLite
-</h1>}
-puts "<p align=center>
-(This page was last modified on [lrange $rcsid 3 4] UTC)
-</p>"
-
+set rcsid {$Id: arch.tcl,v 1.16 2004/10/10 17:24:54 drh Exp $}
+source common.tcl
+header {Architecture of SQLite}
 puts {
-<h2>Introduction</h2>
+<h2>The Architecture Of SQLite</h2>
+
+<h3>Introduction</h3>
 
 <table align="right" border="1" cellpadding="15" cellspacing="1">
 <tr><th>Block Diagram Of SQLite</th></tr>
@@ -33,52 +24,40 @@ and how they interrelate is shown at the right.  The text that
 follows will provide a quick overview of each of these components.
 </p>
 
-<h2>History</h2>
 
 <p>
-There are two main C interfaces to the SQLite library:
-<b>sqlite_exec()</b> and <b>sqlite_compile()</b>.  Prior to
-version 2.8.0 (2003-Feb-16) only sqlite_exec() was supported.
-For version 2.8.0, the sqlite_exec and sqlite_compile methods
-existed as peers.  Beginning with version 2.8.13, the sqlite_compile
-method is the primary interface, and sqlite_exec is implemented
-using sqlite_compile.  Externally, this change is an enhancement
-that maintains backwards compatibility.  But internally,
-the plumbing is very different.  The diagram at the right shows
-the structure of SQLite for version 2.8.13 and following.
+This document describes SQLite version 3.0.  Version 2.8 and
+earlier are similar but the details differ.
 </p>
 
-<h2>Interface</h2>
+<h3>Interface</h3>
 
 <p>Much of the public interface to the SQLite library is implemented by
-functions found in the <b>main.c</b> source file though some routines are
+functions found in the <b>main.c</b>, <b>legacy.c</b>, and
+<b>vdbeapi.c</b> source files
+though some routines are
 scattered about in other files where they can have access to data 
 structures with file scope.  The
-<b>sqlite_get_table()</b> routine is implemented in <b>table.c</b>.
-<b>sqlite_step()</b> is found in <b>vdbe.c</b>.  
-<b>sqlite_mprintf()</b> is found in <b>printf.c</b>.
+<b>sqlite3_get_table()</b> routine is implemented in <b>table.c</b>.
+<b>sqlite3_mprintf()</b> is found in <b>printf.c</b>.
+<b>sqlite3_complete()</b> is in <b>tokenize.c</b>.
 The Tcl interface is implemented by <b>tclsqlite.c</b>.  More
 information on the C interface to SQLite is
-<a href="c_interface.html">available separately</a>.<p>
+<a href="capi3ref.html">available separately</a>.<p>
 
 <p>To avoid name collisions with other software, all external
-symbols in the SQLite library begin with the prefix <b>sqlite</b>.
+symbols in the SQLite library begin with the prefix <b>sqlite3</b>.
 Those symbols that are intended for external use (in other words,
 those symbols which form the API for SQLite) begin
-with <b>sqlite_</b>.</p>
+with <b>sqlite3_</b>.</p>
 
-<h2>SQL Command Process</h2>
-
-<p>
-
-<h2>Tokenizer</h2>
+<h3>Tokenizer</h3>
 
 <p>When a string containing SQL statements is to be executed, the
 interface passes that string to the tokenizer.  The job of the tokenizer
 is to break the original string up into tokens and pass those tokens
-one by one to the parser.  The tokenizer is hand-coded in C.
-All of the code for the tokenizer
-is contained in the <b>tokenize.c</b> source file.</p>
+one by one to the parser.  The tokenizer is hand-coded in C in 
+the file <b>tokenize.c</b>.
 
 <p>Note that in this design, the tokenizer calls the parser.  People
 who are familiar with YACC and BISON may be used to doing things the
@@ -87,7 +66,7 @@ of SQLite
 has done it both ways and finds things generally work out nicer for
 the tokenizer to call the parser.  YACC has it backwards.</p>
 
-<h2>Parser</h2>
+<h3>Parser</h3>
 
 <p>The parser is the piece that assigns meaning to tokens based on
 their context.  The parser for SQLite is generated using the
@@ -106,27 +85,37 @@ SQLite distribution in the "tool" subdirectory.  Documentation on
 lemon is found in the "doc" subdirectory of the distribution.
 </p>
 
-<h2>Code Generator</h2>
+<h3>Code Generator</h3>
 
 <p>After the parser assembles tokens into complete SQL statements,
 it calls the code generator to produce virtual machine code that
 will do the work that the SQL statements request.  There are many
-files in the code generator:  <b>build.c</b>, <b>copy.c</b>,
+files in the code generator:
+<b>attach.c</b>,
+<b>auth.c</b>,
+<b>build.c</b>,
 <b>delete.c</b>,
-<b>expr.c</b>, <b>insert.c</b>, <b>pragma.c</b>,
-<b>select.c</b>, <b>trigger.c</b>, <b>update.c</b>, <b>vacuum.c</b>
+<b>expr.c</b>,
+<b>insert.c</b>,
+<b>pragma.c</b>,
+<b>select.c</b>,
+<b>trigger.c</b>,
+<b>update.c</b>,
+<b>vacuum.c</b>
 and <b>where.c</b>.
 In these files is where most of the serious magic happens.
 <b>expr.c</b> handles code generation for expressions.
 <b>where.c</b> handles code generation for WHERE clauses on
-SELECT, UPDATE and DELETE statements.  The files <b>copy.c</b>,
+SELECT, UPDATE and DELETE statements.  The files <b>attach.c</b>,
 <b>delete.c</b>, <b>insert.c</b>, <b>select.c</b>, <b>trigger.c</b>
 <b>update.c</b>, and <b>vacuum.c</b> handle the code generation
 for SQL statements with the same names.  (Each of these files calls routines
 in <b>expr.c</b> and <b>where.c</b> as necessary.)  All other
-SQL statements are coded out of <b>build.c</b>.</p>
+SQL statements are coded out of <b>build.c</b>.
+The <b>auth.c</b> file implements the functionality of
+<b>sqlite3_set_authorizer()</b>.</p>
 
-<h2>Virtual Machine</h2>
+<h3>Virtual Machine</h3>
 
 <p>The program generated by the code generator is executed by
 the virtual machine.  Additional information about the virtual
@@ -144,42 +133,42 @@ between the virtual machine and the rest of the SQLite library and
 <b>vdbeInt.h</b> which defines structure private the virtual machine.
 The <b>vdbeaux.c</b> file contains utilities used by the virtual
 machine and interface modules used by the rest of the library to
-construct VM programs.</p>
+construct VM programs.  The <b>vdbeapi.c</b> file contains external
+interfaces to the virtual machine such as the 
+<b>sqlite3_bind_...</b> family of functions.  Individual values
+(strings, integer, floating point numbers, and BLOBs) are stored
+in an internal object named "Mem" which is implemented by
+<b>vdbemem.c</b>.</p>
 
-<h2>Backend</h2>
-
-<p>The backend is an abstraction layer that presents a uniform interface
-to the virtual machine for either the B-Tree drivers for disk-based
-databases or the Red/Black Tree driver for in-memory databases.
-The <b>btree.h</b> source file contains the details.</p>
-
-<h2>Red/Black Tree</h2>
-
-<p>In-memory databases are stored in a red/black tree implementation
-contain in the <b>btree_rb.c</b> source file.
+<p>
+SQLite implements SQL functions using callbacks to C-language routines.
+Even the built-in SQL functions are implemented this way.  Most of
+the built-in SQL functions (ex: <b>coalesce()</b>, <b>count()</b>,
+<b>substr()</b>, and so forth) can be found in <b>func.c</b>.
+Date and time conversion functions are found in <b>date.c</b>.
 </p>
 
-<h2>B-Tree</h2>
+<h3>B-Tree</h3>
 
 <p>An SQLite database is maintained on disk using a B-tree implementation
 found in the <b>btree.c</b> source file.  A separate B-tree is used for
 each table and index in the database.  All B-trees are stored in the
-same disk file.  Each page of a B-tree is 1024 bytes in size.  The key
-and data for an entry are stored together in an area called "payload".
-Up to 236 bytes of payload can be stored on the same page as the B-tree
-entry.  Any additional payload is stored in a chain of overflow pages.</p>
+same disk file.  Details of the file format are recorded in a large
+comment at the beginning of <b>btree.c</b>.</p>
 
 <p>The interface to the B-tree subsystem is defined by the header file
 <b>btree.h</b>.
 </p>
 
-<h2>Page Cache</h2>
+<h3>Page Cache</h3>
 
-<p>The B-tree module requests information from the disk in 1024 byte
-chunks.  The page cache is reponsible for reading, writing, and
+<p>The B-tree module requests information from the disk in fixed-size
+chunks.  The default chunk size is 1024 bytes but can vary between 512
+and 65536 bytes.
+The page cache is responsible for reading, writing, and
 caching these chunks.
 The page cache also provides the rollback and atomic commit abstraction
-and takes care of reader/writer locking of the database file.  The
+and takes care of locking of the database file.  The
 B-tree driver requests particular pages from the page cache and notifies
 the page cache when it wants to modify pages or commit or rollback
 changes and the page cache handles all the messy details of making sure
@@ -190,25 +179,43 @@ source file <b>pager.c</b>.  The interface to the page cache subsystem
 is defined by the header file <b>pager.h</b>.
 </p>
 
-<h2>OS Interface</h2>
+<h3>OS Interface</h3>
 
 <p>
 In order to provide portability between POSIX and Win32 operating systems,
 SQLite uses an abstraction layer to interface with the operating system.
-The <b>os.c</b> file contains about 20 routines used for opening and
-closing files, deleting files, creating and deleting locks on files,
-flushing the disk cache, and so forth.  Each of these functions contains
-two implementations separated by #ifdefs: one for POSIX and the other
-for Win32.  The interface to the OS abstraction layer is defined by
-the <b>os.h</b> header file.
+The interface to the OS abstraction layer is defined in
+<b>os.h</b>.  Each supported operating system has its own implementation:
+<b>os_unix.c</b> for Unix, <b>os_win.c</b> for windows, and so forth.
+Each of these operating-specific implements typically has its own
+header file: <b>os_unix.h</b>, <b>os_win.h</b>, etc.
 </p>
+
+<h3>Utilities</h3>
+
+<p>
+Memory allocation and caseless string comparison routines are located
+in <b>util.c</b>.
+Symbol tables used by the parser are maintained by hash tables found
+in <b>hash.c</b>.  The <b>utf.c</b> source file contains Unicode
+conversion subroutines.
+SQLite has its own private implementation of <b>printf()</b> (with
+some extensions) in <b>printf.c</b> and its own random number generator
+in <b>random.c</b>.
+</p>
+
+<h3>Test Code</h3>
+
+<p>
+If you count regression test scripts,
+more than half the total code base of SQLite is devoted to testing.
+There are many <b>assert()</b> statements in the main code files.
+In additional, the source files <b>test1.c</b> through <b>test5.c</b>
+together with <b>md5.c</b> implement extensions used for testing
+purposes only.  The <b>os_test.c</b> backend interface is used to
+simulate power failures to verify the crash-recovery mechanism in
+the pager.
+</p>
+
 }
-
-puts {
-<br clear="both" />
-<p><hr /></p>
-<p><a href="index.html"><img src="/goback.jpg" border=0 />
-Back to the SQLite Home Page</a>
-</p>
-
-</body></html>}
+footer $rcsid
