@@ -1,7 +1,7 @@
 #
 # Run this Tcl script to generate the lang-*.html files.
 #
-set rcsid {$Id: lang.tcl,v 1.97 2005/08/23 11:03:03 drh Exp $}
+set rcsid {$Id: lang.tcl,v 1.89 2005/03/21 01:24:02 drh Exp $}
 source common.tcl
 
 if {[llength $argv]>0} {
@@ -76,7 +76,6 @@ foreach {section} [lsort -index 0 -dictionary {
   {{DETACH DATABASE} detach}
   {REINDEX reindex}
   {{ALTER TABLE} altertable}
-  {{ANALYZE} analyze}
 }] {
   foreach {s_title s_tag} $section {}
   puts "<li><a href=\"[slink $s_tag]\">$s_title</a></li>"
@@ -188,35 +187,6 @@ be readable by SQLite version 3.1.3 and earlier until the database
 is <a href="lang_vacuum.html">VACUUM</a>ed.</p>
 }
 
-Section {ANALYZE} analyze
-
-Syntax {sql-statement} {
-  ANALYZE
-}
-Syntax {sql-statement} {
-  ANALYZE <database-name>
-}
-Syntax {sql-statement} {
-  ANALYZE [<database-name> .] <table-name>
-}
-
-puts {
-<p>The ANALYZE command gathers statistics about indices and stores them
-in a special tables in the database where the query optimizer can use
-them to help make better index choices.
-If no arguments are given, all indices in all attached databases are
-analyzed.  If a database name is given as the argument, all indices
-in that one database are analyzed.  If the argument is a table name,
-then only indices associated with that one table are analyzed.</p>
-
-<p>The initial implementation stores all statistics in a single
-table named <b>sqlite_stat1</b>.  Future enhancements may create
-additional tables with the same name pattern except with the "1"
-changed to a different digit.  The <b>sqlite_stat1</b> table cannot
-be DROPped, but it all the content can be DELETEd which as the
-same effect.</p>
-}
-
 Section {ATTACH DATABASE} attach
 
 Syntax {sql-statement} {
@@ -571,16 +541,15 @@ on automatic B-Tree key generation is available
 <a href="autoinc.html">separately</a>.</p>
 
 <p>If the "TEMP" or "TEMPORARY" keyword occurs in between "CREATE"
-and "TABLE" then the table that is created is only visible
-within that same database connection
-and is automatically deleted when
-the database connection is closed.  Any indices created on a temporary table
+and "TABLE" then the table that is created is only visible to the
+process that opened the database and is automatically deleted when
+the database is closed.  Any indices created on a temporary table
 are also temporary.  Temporary tables and indices are stored in a
 separate file distinct from the main database file.</p>
 
-<p> If a &lt;database-name&gt; is specified, then the table is created in 
-the named database. It is an error to specify both a &lt;database-name&gt;
-and the TEMP keyword, unless the &lt;database-name&gt; is "temp". If no
+<p> If a <database-name> is specified, then the table is created in 
+the named database. It is an error to specify both a <database-name>
+and the TEMP keyword, unless the <database-name> is "temp". If no
 database name is specified, and the TEMP keyword is not present,
 the table is created in the main database.</p>
 
@@ -780,7 +749,8 @@ the statement that caused the trigger program to execute and any subsequent
 </p>
 
 <p>Triggers are removed using the <a href="#droptrigger">DROP TRIGGER</a>
-statement.</p>
+statement.  Non-temporary triggers cannot be added on a table in an 
+attached database.</p>
 }
 
 
@@ -798,7 +768,7 @@ of another SELECT in place of a table name.
 </p>
 
 <p>If the "TEMP" or "TEMPORARY" keyword occurs in between "CREATE"
-and "VIEW" then the view that is created is only visible to the
+and "TABLE" then the table that is created is only visible to the
 process that opened the database and is automatically deleted when
 the database is closed.</p>
 
@@ -812,7 +782,8 @@ the table is created in the main database.</p>
 in SQLite.  However, in many cases you can use a <a href="#createtrigger">
 TRIGGER</a> on the view to accomplish the same thing.  Views are removed 
 with the <a href="#dropview">DROP VIEW</a> 
-command.</p>
+command.  Non-temporary views cannot be created on tables in an attached 
+database.</p>
 }
 
 
@@ -865,11 +836,9 @@ the disk.  The only way to recover the index is to reenter the
 appropriate CREATE INDEX command.</p>
 
 <p>The DROP INDEX statement does not reduce the size of the database 
-file in the default mode.
-Empty space in the database is retained for later INSERTs.  To 
+file.  Empty space in the database is retained for later INSERTs.  To 
 remove free space in the database, use the <a href="#vacuum">VACUUM</a> 
-command.  If AUTOVACUUM mode is enabled for a database then space
-will be freed automatically by DROP INDEX.</p>
+command.</p>
 }
 
 
@@ -884,14 +853,13 @@ puts {
 "#createtable">CREATE TABLE</a> statement.  The name specified is the
 table name.  It is completely removed from the database schema and the 
 disk file.  The table can not be recovered.  All indices associated 
-with the table are also deleted.</p>
+with the table are also deleted.  Non-temporary tables in an attached 
+database cannot be dropped.</p>
 
 <p>The DROP TABLE statement does not reduce the size of the database 
-file in the default mode.  Empty space in the database is retained for
-later INSERTs.  To 
+file.  Empty space in the database is retained for later INSERTs.  To 
 remove free space in the database, use the <a href="#vacuum">VACUUM</a> 
-command.  If AUTOVACUUM mode is enabled for a database then space
-will be freed automatically by DROP TABLE.</p>
+command.</p>
 }
 
 
@@ -903,7 +871,8 @@ puts {
 <p>The DROP TRIGGER statement removes a trigger created by the 
 <a href="#createtrigger">CREATE TRIGGER</a> statement.  The trigger is 
 deleted from the database schema. Note that triggers are automatically 
-dropped when the associated table is dropped.</p>
+dropped when the associated table is dropped.  Non-temporary triggers 
+cannot be dropped on attached tables.</p>
 }
 
 
@@ -917,7 +886,8 @@ puts {
 <p>The DROP VIEW statement removes a view created by the <a href=
 "#createview">CREATE VIEW</a> statement.  The name specified is the 
 view name.  It is removed from the database schema, but no actual data 
-in the underlying base tables is modified.</p>
+in the underlying base tables is modified.  Non-temporary views in 
+attached databases cannot be dropped.</p>
 }
 
 
@@ -946,14 +916,14 @@ Section expression expr
 
 Syntax {expr} {
 <expr> <binary-op> <expr> |
-<expr> [NOT] <like-op> <expr> [ESCAPE <expr>] |
+<expr> <like-op> <expr> [ESCAPE <expr>] |
+<expr> <glob-op> <expr> |
 <unary-op> <expr> |
 ( <expr> ) |
 <column-name> |
 <table-name> . <column-name> |
 <database-name> . <table-name> . <column-name> |
 <literal-value> |
-<parameter> |
 <function-name> ( <expr-list> | STAR ) |
 <expr> ISNULL |
 <expr> NOTNULL |
@@ -962,10 +932,11 @@ Syntax {expr} {
 <expr> [NOT] IN ( <select-statement> ) |
 <expr> [NOT] IN [<database-name> .] <table-name> |
 [EXISTS] ( <select-statement> ) |
-CASE [<expr>] LP WHEN <expr> THEN <expr> RPPLUS [ELSE <expr>] END |
-CAST ( <expr> AS <type> )
+CASE [<expr>] LP WHEN <expr> THEN <expr> RPPLUS [ELSE <expr>] END
 } {like-op} {
-LIKE | GLOB | REGEXP
+LIKE | NOT LIKE
+} {glob-op} {
+GLOB | NOT GLOB
 }
 
 puts {
@@ -994,7 +965,12 @@ OR</font>
 <font color="#2c2cf0"><big>-    +    !    ~</big></font>
 </pre></blockquote>
 
-<p>Note that there are two variations of the equals and not equals
+<p>Any SQLite value can be used as part of an expression.  
+For arithmetic operations, integers are treated as integers.
+Strings are first converted to real numbers using <b>atof()</b>.
+For comparison operators, numbers compare as numbers and strings
+compare using the <b>strcmp()</b> function.
+Note that there are two variations of the equals and not equals
 operators.  Equals can be either}
 puts "[Operator =] or [Operator ==].
 The non-equals operator can be either
@@ -1002,77 +978,9 @@ The non-equals operator can be either
 The [Operator ||] operator is \"concatenate\" - it joins together
 the two strings of its operands.
 The operator [Operator %] outputs the remainder of its left 
-operand modulo its right operand.</p>
-
-<p>The result of any binary operator is a numeric value, except
-for the [Operator ||] concatenation operator which gives a string
-result.</p>"
-
+operand modulo its right operand.</p>"
 puts {
 
-<a name="literal_value"></a>
-<p>
-A literal value is an integer number or a floating point number.
-Scientific notation is supported.  The "." character is always used
-as the decimal point even if the locale setting specifies "," for
-this role - the use of "," for the decimal point would result in
-syntactic ambiguity.  A string constant is formed by enclosing the
-string in single quotes (').  A single quote within the string can
-be encoded by putting two single quotes in a row - as in Pascal.
-C-style escapes using the backslash character are not supported because
-they are not standard SQL.
-BLOB literals are string literals containing hexadecimal data and
-preceded by a single "x" or "X" character.  For example:</p>
-
-<blockquote><pre>
-X'53514697465'
-</pre></blockquote>
-
-<p>
-A literal value can also be the token "NULL".
-</p>
-
-<p>
-A parameter specifies a placeholder in the expression for a literal
-value that is filled in at runtime using the
-<a href="capi3ref.html#sqlite3_bind_int">sqlite3_bind</a> API.
-Parameters can take several forms:
-</p
-
-<blockquote>
-<table>
-<tr>
-<td align="right" valign="top"><b>?</b><i>NNN</i></td><td width="20"></td>
-<td>A question mark followed by a number <i>NNN</i> holds a spot for the
-NNN-th parameter.  NNN must be between 1 and 999.</td>
-</tr>
-<tr>
-<td align="right" valign="top"><b>?</b></td><td width="20"></td>
-<td>A question mark that is not followed by a number holds a spot for
-the next unused parameter.</td>
-</tr>
-<tr>
-<td align="right" valign="top"><b>:</b><i>AAAA</i></td><td width="20"></td>
-<td>A colon followed by an identifier name holds a spot for a named
-parameter with the name AAAA.  Named parameters are also numbered.
-The number assigned is the next unused number.  To avoid confusion,
-it is best to avoid mixing named and numbered parameters.</td>
-</tr>
-<tr>
-<td align="right" valign="top"><b>$</b><i>AAAA</i></td><td width="20"></td>
-<td>A dollar-sign followed by an identifier name also holds a spot for a named
-parameter with the name AAAA.  The identifier name in this case can include
-one or more occurances of "::" and a suffix enclosed in "(...)" containing
-any text at all.  This syntax is the form of a variable name in the Tcl
-programming language.</td>
-</tr>
-</table>
-</blockquote>
-
-<p>Parameters that are not assigned values using
-<a href="capi3ref.html#sqlite3_bind_int">sqlite3_bind</a> are treated
-as NULL.</p>
-
 <a name="like"></a>
 <p>The LIKE operator does a pattern matching comparison. The operand
 to the right contains the pattern, the left hand operand contains the
@@ -1106,14 +1014,9 @@ characters on one side against lower case characters on the other.
 characters.  Hence the LIKE operator is case sensitive for 8-bit
 iso8859 characters or UTF-8 characters.  For example, the expression
 <b>'a'&nbsp;LIKE&nbsp;'A'</b> is TRUE but
-<b>'&aelig;'&nbsp;LIKE&nbsp;'&AElig;'</b> is FALSE.).</p>
-
-<p>The infix LIKE
-operator is implemented by calling the user function <a href="#likeFunc">
-like(<i>X</i>,<i>Y</i>)</a>.  If an ESCAPE clause is present, it adds
-a third parameter to the function call. If the functionality of LIKE can be
-overridden by defining an alternative implementation of the
-like() SQL function.</p>
+<b>'&aelig;'&nbsp;LIKE&nbsp;'&AElig;'</b> is FALSE.).  The infix LIKE
+operator is identical the user function <a href="#likeFunc">
+like(<i>X</i>,<i>Y</i>)</a>.
 </p>
 
 <a name="glob"></a>
@@ -1121,17 +1024,8 @@ like() SQL function.</p>
 file globbing syntax for its wildcards.  Also, GLOB is case
 sensitive, unlike LIKE.  Both GLOB and LIKE may be preceded by
 the NOT keyword to invert the sense of the test.  The infix GLOB 
-operator is implemented by calling the user function <a href="#globFunc">
-glob(<i>X</i>,<i>Y</i>)</a> and can be modified by overriding
-that function.</p>
-
-<a name="regexp"></a>
-<p>The REGEXP operator is a special syntax for the regexp()
-user function.  No regexp() user function is defined by default
-and so use of the REGEXP operator will normally result in an
-error message.  If a user-defined function named "regexp"
-is defined at run-time, that function will be called in order
-to implement the REGEXP operator.</p>
+operator is identical the user function <a href="#globFunc">
+glob(<i>X</i>,<i>Y</i>)</a>.</p>
 
 <p>A column name can be any of the names defined in the CREATE TABLE
 statement or one of the following special identifiers: "<b>ROWID</b>",
@@ -1173,11 +1067,6 @@ SELECT becomes the value used in the expression.  If the SELECT yields
 more than one result row, all rows after the first are ignored.  If
 the SELECT yields no rows, then the value of the SELECT is NULL.</p>
 
-<p>A CAST expression changes the datatype of the <expr> into the
-type specified by &lt;type&gt;. 
-&lt;type&gt; can be any non-empty type name that is valid
-for the type in a column definition of a CREATE TABLE statement.</p>
-
 <p>Both simple and aggregate functions are supported.  A simple
 function can be used in any expression.  Simple functions return
 a result immediately based on their inputs.  Aggregate functions
@@ -1210,7 +1099,7 @@ all arguments are NULL then NULL is returned.  There must be at least
 <a href="capi3ref.html#sqlite3_create_function">sqlite3_create_function()</a> 
 interface can
 be used to override this function and thereby change the operation
-of the <a href="#globFunc">GLOB</a> operator.</td>
+of the <a href="#glob">GLOB</a> operator.</td>
 </tr>
 
 <tr>
@@ -1515,7 +1404,8 @@ Syntax {sql-statement} {
 
 puts {
 <p>The REINDEX command is used to delete and recreate indices from scratch.
-This is useful when the definition of a collation sequence has changed.
+This is primarily useful when the definition of a collation sequence has 
+changed.
 </p>
 
 <p>In the first form, all indices in all attached databases that use the
