@@ -1,7 +1,7 @@
 #
 # Run this Tcl script to generate the tclsqlite.html file.
 #
-set rcsid {$Id: tclsqlite.tcl,v 1.14 2005/08/02 17:38:19 drh Exp $}
+set rcsid {$Id: tclsqlite.tcl,v 1.12 2004/12/17 15:41:13 tpoindex Exp $}
 source common.tcl
 header {The Tcl interface to the SQLite library}
 proc METHOD {name text} {
@@ -46,7 +46,7 @@ the database is stored.
 
 <p>
 Once an SQLite database is open, it can be controlled using 
-methods of the <i>dbcmd</i>.  There are currently 19 methods
+methods of the <i>dbcmd</i>.  There are currently 18 methods
 defined:</p>
 
 <p>
@@ -66,13 +66,11 @@ foreach m [lsort {
  eval
  function
  last_insert_rowid
- nullvalue
  onecolumn
  progress
  timeout
  total_changes
  trace
- transaction
 }] {
  puts "<li><a href=\"#$m\">$m</a></li>"
 }
@@ -231,44 +229,6 @@ since it avoids making a copy of the content of $bigblob.
 
 }
 
-##############################################################################
-METHOD transaction {
-
-<p>
-The "transaction" method is used to execute a TCL script inside an SQLite
-database transaction.  The transaction is committed when the script completes,
-or it rolls back if the script fails.  If the transaction occurs within
-another transaction (even one that is started manually using BEGIN) it
-is a no-op.
-</p>
-
-<p>
-The transaction command can be used to group together several SQLite
-commands in a safe way.  You can always start transactions manually using
-BEGIN, of
-course.  But if an error occurs so that the COMMIT or ROLLBACK are never
-run, then the database will remain locked indefinitely.  Also, BEGIN
-does not nest, so you have to make sure no other transactions are active
-before starting a new one.  The "transaction" method takes care of
-all of these details automatically.
-</p>
-
-<p>
-The syntax looks like this:
-</p>
-
-<blockquote>
-<i>dbcmd</i>&nbsp;&nbsp;<b>transaction</b>&nbsp;&nbsp;<i>?transaction-type?</i>
-&nbsp;&nbsp;<i>SCRIPT,</i>
-</blockquote>
-
-
-<p>
-The <i>transaction-type</i> can be one of <b>deferred</b>,
-<b>exclusive</b> or <b>immediate</b>.  The default is deferred.
-</p>
-}
-
 ##############################################################################
 METHOD complete {
 
@@ -405,24 +365,6 @@ db function hex {format 0x%X}
 
 }
 
-##############################################################################
-METHOD nullvalue {
-
-<p>
-The "nullvalue" method changes the representation for NULL returned
-as result of the "eval" method.</p>
-
-<blockquote><b>
-db1 nullvalue NULL
-</b></blockquote>
-
-<p>The "nullvalue" method is useful to differ between NULL and empty
-column values as Tcl lacks a NULL representation.  The default
-representation for NULL values is an empty string.</p>
-}
-
-
-
 ##############################################################################
 METHOD onecolumn {
 
